@@ -173,6 +173,8 @@ test_that("[add_]epred_rvars works on brms models with ordinal outcomes (respons
 
 test_that("[add_]epred_rvars works on brms models with dirichlet outcomes (response scale)", {
   skip_if_not_installed("brms")
+  skip_if_not(getRversion() >= "4")
+
   m_dirich = readRDS(test_path("../models/models.brms.m_dirich.rds"))
 
   grid = tibble(x = c("A", "B"))
@@ -219,4 +221,7 @@ test_that("[add_]epred_rvars throws an error when re.form is called instead of r
 
 # unknown model type tests ------------------------------------------------
 
-
+test_that("rethinking model usage refers user to tidybayes.rethinking", {
+  m = structure(list(), class = "map2stan")
+  expect_error(epred_rvars(m), "tidybayes.rethinking")
+})
