@@ -9,7 +9,7 @@ suppressWarnings(suppressMessages({
   library(magrittr)
 }))
 
-context("gather_emmeans_draws")
+
 
 
 # data
@@ -63,10 +63,13 @@ test_that("gather_emmeans_draws works on an emm_list", {
   grid_list = emmeans::ref_grid(m_hp_wt, estimate_grid, data = mtcars_tbl) %>%
     emmeans::emmeans(pairwise ~ hp|wt)
 
-  ref = map_dfr(grid_list, ~ gather_emmeans_draws(.x) %>%
-      ungroup() %>%
-      mutate_at(vars(matches("contrast")), as.character),
-    .id = ".grid"
+  ref = bind_rows(
+      lapply(unclass(grid_list), . %>%
+        gather_emmeans_draws() %>%
+        ungroup() %>%
+        mutate_at(vars(matches("contrast")), as.character)
+      ),
+      .id = ".grid"
     ) %>%
     group_by(hp, wt, contrast, .grid)
 
